summaryrefslogtreecommitdiff
path: root/framework/Data/TMemCache.php
diff options
context:
space:
mode:
Diffstat (limited to 'framework/Data/TMemCache.php')
-rw-r--r--framework/Data/TMemCache.php4
1 files changed, 2 insertions, 2 deletions
diff --git a/framework/Data/TMemCache.php b/framework/Data/TMemCache.php
index 4d952551..9786b467 100644
--- a/framework/Data/TMemCache.php
+++ b/framework/Data/TMemCache.php
@@ -97,7 +97,7 @@ class TMemCache extends TComponent implements IModule, ICache
* This method is required by the IModule interface. It makes sure that
* UniquePrefix has been set, creates a Memcache instance and connects
* to the memcache server.
* @param IApplication Prado application, can be null
* @param TXmlElement configuration for this module, can be null
* @throws TConfigurationException if memcache extension is not installed or memcache sever connection fails
*/
@@ -108,7 +108,7 @@ class TMemCache extends TComponent implements IModule, ICache
$this->_cache=new Memcache;
if($this->_cache->connect($this->_host,$this->_port)===false)
throw new TInvalidConfigurationException('memcache_connection_failed');
- if($application instanceof IApplication)
+ if($application instanceof TApplication)
$this->_prefix=$application->getUniqueID();
$this->_initialized=true;
$application->setCache($this);
@@ -97,7 +97,7 @@ class TMemCache extends TComponent implements IModule, ICache
* UniquePrefix has been set, creates a Memcache instance and connects
* to the memcache server.
- * @param IApplication Prado application, can be null
+ * @param TApplication Prado application, can be null
* @param TXmlElement configuration for this module, can be null
* @throws TConfigurationException if memcache extension is not installed or memcache sever connection fails